@@ -20,10 +20,15 @@
 #include <unistd.h>
 #include <string.h>
 #include <getopt.h>
+#include <errno.h>
 #include <sys/ioctl.h>
 #include <linux/input.h>
 #include <gtk/gtk.h>
 
+#ifdef HAVE_LANGINFO_CODESET
+#  include <langinfo.h>
+#endif
+
 #include <pbb.h>
 
 #include "init.h"
@@ -33,10 +38,10 @@
 #include "support.h"
 #include "gettext_macros.h"
 
-extern volatile int prgexit;
+extern volatile sig_atomic_t prgexit;
 
 int
-init_powerprefs(struct basedata *base)
+init_powerprefs (struct basedata *base)
 {
 	int rc;
 
@@ -49,7 +54,8 @@ init_powerprefs(struct basedata *base)
 	base->ac.policy = 0;
 	base->battery.policy = 0;
 
-	if ((rc = ipc_init (LIBMODE_CLIENT, 1)) != 0) {  /* setup IPC subsystem for clients */
+	/* setup IPC system for clients */
+	if ((rc = ipc_init ("PowerPrefs", LIBMODE_CLIENT, CLIENT_REGISTER)) != 0) {
 		if (rc == E_NOSERVER)
 			print_error (_("ERROR: Server message port not found. Server isn't running.\n"));
 		else if (rc == E_REGISTER)
@@ -135,8 +141,11 @@ evaluate_args(int argc, char *argv[])
 		  {NULL, 0, NULL, 0}
 	};
 	char *prgname;
-	int c;
+	int c, err = 0;
 
+#if defined(ENABLE_NLS) && defined(HAVE_LANGINFO_CODESET)
+	bind_textdomain_codeset (GETTEXT_PACKAGE, nl_langinfo(CODESET));
+#endif
 	if((prgname = strrchr(argv[0],'/')) == NULL)
 		prgname = argv[0];
 	else prgname++;		/* ignore first slash*/
@@ -146,8 +155,9 @@ evaluate_args(int argc, char *argv[])
 		switch (c) {
 			case ARG_VERSION:
 				printf(_("%s, version %s"), PACKAGE, VERSION);
-				printf(", (c) 2002 Matthias Grimm\n");
-				return E_INFO;;
+				printf(", (c) 2002-2005 Matthias Grimm\n");
+				err = E_INFO;
+				break;
 			case ARG_HELP:
 			default:
 				printf(_("%s - Preferences client for pbbuttonsd, make some options easy accessable.\n"), prgname);
@@ -156,10 +166,16 @@ evaluate_args(int argc, char *argv[])
 					"   -%c, --help           display this help and exit\n"
 					"   -%c, --version        display version information and exit\n"),
 					ARG_HELP, ARG_VERSION);
-				return E_INFO;
+				err = E_INFO;
+				break;
 		}
+		if (err != 0)
+			break; /* while */
 	}
-	return 0;
+#ifdef ENABLE_NLS
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+	return err;
 }
 
 int
@@ -180,14 +196,18 @@ init_guicontrol (struct basedata *base)
 	  { TAG_TPMODEUPMOD,        "ms_entry_tpmodeupkey",   NULL, th_modentry,   0},
 	  { TAG_TPMODEDOWNKEY,      "ms_entry_tpmodednkey",   NULL, th_keyentry,   0},
 	  { TAG_TPMODEDOWNMOD,      "ms_entry_tpmodednkey",   NULL, th_modentry,   0},
+	  { TAG_NOTAPTYPING,        "ms_check_notaptyping",   NULL, th_checkbox,   0},
 	  /* cdrom / general */
 	  { TAG_CDROMDEVICE,        "dr_entry_cdromdev",      NULL, th_textentry,  0},
 	  { TAG_EJECTCDKEYDELAY,    "dr_check_ejectcddelay",  NULL, th_checkbox,   0},
 	  { TAG_EJECTCDKEY,         "dr_entry_ejectcdkey",    NULL, th_keyentry,   0},
 	  { TAG_EJECTCDMOD,         "dr_entry_ejectcdkey",    NULL, th_modentry,   0},
 	  /* audio / general */
-	  { TAG_MIXERDEVICE,        "au_entry_mixerdev",      NULL, th_textentry,  0},
-	  { TAG_MIXERCHANNELS,      "au_entry_channels",      NULL, th_textentry,  0},
+	  { TAG_SOUNDSYSTEMCFG,     "au_radio_sound",         NULL, th_radiobutton,0},
+	  { TAG_MIXERDEVICE,        "au_entry_ossdevice",     NULL, th_textentry,  0},
+	  { TAG_MIXERCARD,          "au_entry_alsacard",      NULL, th_textentry,  0},
+	  { TAG_MIXERCHANNELS,      "au_entry_osschannels",   NULL, th_textentry,  0},
+	  { TAG_MIXERELEMENTS,      "au_entry_alsaelements",  NULL, th_textentry,  0},
 	  { TAG_MIXERINITDELAY,     "au_check_delaymixer",    NULL, th_checkbox,   0},
 	  { TAG_VOLUMEUPKEY,        "au_entry_volupkey",      NULL, th_keyentry,   0},
 	  { TAG_VOLUMEUPMOD,        "au_entry_volupkey",      NULL, th_modentry,   0},
@@ -195,6 +215,7 @@ init_guicontrol (struct basedata *base)
 	  { TAG_VOLUMEDOWNMOD,      "au_entry_voldnkey",      NULL, th_modentry,   0},
 	  { TAG_MUTEKEY,            "au_entry_mutekey",       NULL, th_keyentry,   0},
 	  { TAG_MUTEMOD,            "au_entry_mutekey",       NULL, th_modentry,   0},
+	  { TAG_SOUNDSYSTEM,        "au_label_soundsystem",   NULL, th_soundsystem,0},
 	  /* video / LCD */
 	  { TAG_LCDBRIGHTNESS,      "vi_itext_lcdbrightness", NULL, th_showvalue,  GCF_RONLY},
 	  { TAG_LCDILLUMUPKEY,      "vi_entry_lcdbrightupkey",NULL, th_keyentry,   0},
@@ -225,6 +246,8 @@ init_guicontrol (struct basedata *base)
 	  /* video / options */
 	  { TAG_FRAMEBUFFERDEVICE,  "vi_entry_fbdev",         NULL, th_textentry,  0},
 	  { TAG_BLANKFRAMEBUFFER,   "vi_check_blankfb",       NULL, th_checkbox,   0},
+	  { TAG_CRTMIRRORKEY,       "vi_entry_extvideokey",   NULL, th_keyentry,   0},
+	  { TAG_CRTMIRRORMOD,       "vi_entry_extvideokey",   NULL, th_modentry,   0},
 	  /* power / commands */
 	  { TAG_SCRIPTPMCS,         "pv_entry_cmdchprofile",  NULL, th_textentry,  GCF_ROOT},
 	  { TAG_TIMEFORCMD,         "pv_spin_cmdtimeout",     NULL, th_spinbutton, GCF_ROOT},
@@ -272,6 +295,7 @@ init_guicontrol (struct basedata *base)
 	  { 0,  "vi_learn_kbdbrightupkey","vi_entry_kbdbrightupkey",th_dummy, GCF_LEARN},
 	  { 0,  "vi_learn_kbdbrightdnkey","vi_entry_kbdbrightdnkey",th_dummy, GCF_LEARN},
 	  { 0,  "vi_learn_kbdbrightonkey","vi_entry_kbdbrightonkey",th_dummy, GCF_LEARN},
+	  { 0,  "vi_learn_extvideokey",   "vi_entry_extvideokey",   th_dummy, GCF_LEARN},
 	  { 0,  "au_learn_volupkey",      "au_entry_volupkey",      th_dummy, GCF_LEARN},
 	  { 0,  "au_learn_voldnkey",      "au_entry_voldnkey",      th_dummy, GCF_LEARN},
 	  { 0,  "au_learn_mutekey",       "au_entry_mutekey",       th_dummy, GCF_LEARN},
@@ -309,6 +333,7 @@ void
 gui_finetuning (struct basedata *base)
 {
 	GtkWidget *widget;
+	GSList *radiolist;
 	gchar *text;
 	int n;
 
@@ -321,9 +346,16 @@ gui_finetuning (struct basedata *base)
 		if ((widget = lookup_widget(base->mainwindow, "main_btn_save")))
 			gtk_widget_set_sensitive (widget, FALSE);
 			
+		if ((widget = lookup_widget(base->mainwindow, "au_radio_sound"))) {
+			radiolist = gtk_radio_button_get_group (GTK_RADIO_BUTTON(widget));
+			while (radiolist) {
+				gtk_widget_set_sensitive (GTK_WIDGET (radiolist->data), FALSE);
+				radiolist = g_slist_next(radiolist);
+			}
+		}
 	}
 
-	/* make lean buttons sensitive if learn mode is activated */
+	/* make learn buttons sensitive if learn mode is activated */
 	if (base->flags.learn_activated)
 		for (n=0; n < base->GUIControlCount; n++)
 			if (base->GUIControl[n].flags & GCF_LEARN) {
@@ -391,6 +423,9 @@ collect_kbd_devices(struct basedata *base)
 					close(fd);
 			} else
 				close(fd);
+/*		} else if (errno != ENOENT) {
+			print_error(_("WARNING: Problems accessing event device 'event%d': %s\n"), i, strerror(errno));
+*/
 		}
 	}
 	return n;
