@@ -30,7 +30,7 @@
 extern volatile int prgexit;
 
 int
-set_server_config(struct basedata *base)
+set_server_config (struct basedata *base)
 {
 	int n, d;
 	long nval, oval;
@@ -55,13 +55,14 @@ set_server_config(struct basedata *base)
 		}
 	}
 	ipc_send (0, CHANGEVALUE, taglist); /* setting the options */
-	ipc_send (0, READVALUE, taglist);   /* check if they are really set */
 	free(taglist);
+	
+	get_server_config(base);  /* check if they are really set */
 	return 0;
 }
 
 int
-get_server_config(struct basedata *base)
+get_server_config (struct basedata *base)
 {
 	int n;
 	struct tagitem *taglist;
@@ -73,15 +74,19 @@ get_server_config(struct basedata *base)
 
 	taglist_init(taglist);
 	for (n=0; n < base->GUIControlCount; n++)
-		if (base->GUIControl[n].tag != 0)
-			taglist_add (taglist, base->GUIControl[n].tag, 0);
-
+		if (base->GUIControl[n].tag != 0) {
+			if (base->GUIControl[n].tag & FLG_STRING)
+				taglist_add (taglist, base->GUIControl[n].tag, 0);
+			else
+				taglist_add (taglist, base->GUIControl[n].tag, -1);
+		}
 	ipc_send (0, READVALUE, taglist);
 	free(taglist);
 	return 0;
 }
 
-gint timeout_callback(gpointer data)
+gint
+timeout_callback (gpointer data)
 {
 	struct basedata *base = (struct basedata*) data;
 	char *msgbuffer[MSGMAX];
@@ -98,7 +103,7 @@ gint timeout_callback(gpointer data)
 	if ((ipc_receive (msgbuffer, sizeof(msgbuffer))) == 0) {
 		switch (msg->action) {
 		case REGFAILED:
-			print_error (_("ERROR: Client list full. Server doesn't accept more clients.\n"));
+			print_error (_("ERROR: Client registration denied.\n"));
 			gtk_main_quit();
 			break;
 		case CLIENTEXIT:
