@@ -53,9 +53,9 @@ th_showvalue (int mode, long tag, GtkWidget *widget, long data)
 long
 th_textentry (int mode, long tag, GtkWidget *widget, long data)
 {
-	if (mode == THMODE_SET)
+	if (mode == THMODE_SET) {
 		gtk_entry_set_text(GTK_ENTRY(widget), (gchar*) data);
-	else
+	} else
 		data = (long) gtk_entry_get_text(GTK_ENTRY(widget));
 	return data;
 }
@@ -63,9 +63,9 @@ th_textentry (int mode, long tag, GtkWidget *widget, long data)
 long
 th_checkbox (int mode, long tag, GtkWidget *widget, long data)
 {
-	if (mode == THMODE_SET)
+	if (mode == THMODE_SET) {
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (widget), data ? TRUE : FALSE);
-	else
+	} else
 		data = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 	return data ? 1 : 0;
 }
@@ -101,9 +101,11 @@ th_keyentry (int mode, long tag, GtkWidget *widget, long data)
 	char arg[25];
 
 	if (mode == THMODE_SET) {
-		strncpy (arg, (char*) gtk_entry_get_text(GTK_ENTRY(widget)), sizeof(arg));
-		get_key_and_modifier(arg, &key, &mod);
-		gtk_entry_set_text(GTK_ENTRY(widget), code_key_and_modifier(data, mod));
+		if (data != -1) {
+			strncpy (arg, (char*) gtk_entry_get_text(GTK_ENTRY(widget)), sizeof(arg));
+			get_key_and_modifier(arg, &key, &mod);
+			gtk_entry_set_text(GTK_ENTRY(widget), code_key_and_modifier(data, mod));
+		}
 	} else {
 		strncpy (arg, (char*) gtk_entry_get_text(GTK_ENTRY(widget)), sizeof(arg));
 		get_key_and_modifier(arg, &key, &mod);
@@ -119,9 +121,11 @@ th_modentry (int mode, long tag, GtkWidget *widget, long data)
 	char arg[25];
 
 	if (mode == THMODE_SET) {
-		strncpy (arg, (char*) gtk_entry_get_text(GTK_ENTRY(widget)), sizeof(arg));
-		get_key_and_modifier(arg, &key, &mod);
-		gtk_entry_set_text(GTK_ENTRY(widget), code_key_and_modifier(key, data));
+		if (data != -1) {
+			strncpy (arg, (char*) gtk_entry_get_text(GTK_ENTRY(widget)), sizeof(arg));
+			get_key_and_modifier(arg, &key, &mod);
+			gtk_entry_set_text(GTK_ENTRY(widget), code_key_and_modifier(key, data));
+		}
 	} else {
 		strncpy (arg, (char*) gtk_entry_get_text(GTK_ENTRY(widget)), sizeof(arg));
 		get_key_and_modifier(arg, &key, &mod);
@@ -133,9 +137,10 @@ th_modentry (int mode, long tag, GtkWidget *widget, long data)
 long
 th_spinbutton (int mode, long tag, GtkWidget *widget, long data)
 {
-	if (mode == THMODE_SET)
+	if (mode == THMODE_SET) {
+		if (data == -1) data = 0;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON(widget), (gdouble) data);
-	else
+	} else
 		data = (long) gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(widget));
 	return data;
 }
@@ -143,21 +148,40 @@ th_spinbutton (int mode, long tag, GtkWidget *widget, long data)
 long
 th_combobox (int mode, long tag, GtkWidget *widget, long data)
 {
-	if (mode == THMODE_SET)
+	if (mode == THMODE_SET) {
+		if (data == -1) data = 0;
 		gtk_combo_box_set_active (GTK_COMBO_BOX(widget), (gint) data);
-	else
+	} else
 		data = (long) gtk_combo_box_get_active (GTK_COMBO_BOX(widget));
 	return data;
 }
 
+long
+th_soundsystem (int mode, long tag, GtkWidget *widget, long data)
+{
+	if (mode == THMODE_SET) {
+		if (data == 3)
+			gtk_label_set_text(GTK_LABEL(widget), "Advanced Linux Sound Architecture");
+		else if (data == 2)
+			gtk_label_set_text(GTK_LABEL(widget), "Open Sound System");
+		else
+			gtk_label_set_text(GTK_LABEL(widget), _("not available"));
+}
+	return data;
+}
+
+
 long
 th_system (int mode, long tag, GtkWidget *widget, long data)
 {
 	struct basedata *base = (struct basedata*) &masterdata;
+	GSList *radiolist;
 	GtkWidget *wid;
+	unsigned long val;
 
 	switch(tag) {
 		case TAG_SYSINFO:
+			if (data == -1) data = 0;
 			if (mode == THMODE_SET) {				
 				/* disable sleep functions if sleep is not available */
 				if ((data & SYSINFO_SLEEPSUPPORTED) == 0) {
@@ -188,6 +212,35 @@ th_system (int mode, long tag, GtkWidget *widget, long data)
 				if ((data & SYSINFO_CONFIGWRITABLE) == 0)
 					if ((widget = lookup_widget(base->mainwindow, "main_btn_save")))
 						gtk_widget_set_sensitive (widget, FALSE);
+
+				/* disable OSS notetab if a OSS mixer module is not available
+				 */
+				if ((data & SYSINFO_HAVEOSS) == 0) {
+					if ((wid = lookup_widget(base->mainwindow, "au_func_osstab")))
+						gtk_widget_set_sensitive (wid, FALSE);
+					if ((wid = lookup_widget(base->mainwindow, "au_func_osslab")))
+						gtk_widget_set_sensitive (wid, FALSE);
+				}
+
+				/* disable ALSA notetab if a ALSA mixer module is not available
+				 */
+				if ((data & SYSINFO_HAVEALSA) == 0) {
+					if ((wid = lookup_widget(base->mainwindow, "au_func_alsatab")))
+						gtk_widget_set_sensitive (wid, FALSE);
+					if ((wid = lookup_widget(base->mainwindow, "au_func_alsalab")))
+						gtk_widget_set_sensitive (wid, FALSE);
+				}
+	
+				/* disable sound system options if only one soundsystem is available */
+				val = SYSINFO_HAVEOSS | SYSINFO_HAVEALSA;
+				if ((data & val) != val)
+					if ((widget = lookup_widget(base->mainwindow, "au_radio_sound"))) {
+						radiolist = gtk_radio_button_get_group (GTK_RADIO_BUTTON(widget));
+						while (radiolist) {
+							gtk_widget_set_sensitive (GTK_WIDGET (radiolist->data), FALSE);
+							radiolist = g_slist_next(radiolist);
+						}
+					}
 			}
 			break;
 	}
@@ -198,6 +251,10 @@ long
 th_profile (int mode, long tag, GtkWidget *widget, long data)
 {
 	struct basedata *base = (struct basedata*) &masterdata;
+
+	if (data == -1)   /* tag is not supported */
+		return data;
+	
 	switch(tag) {
 		case TAG_ONAC_POLICY:
 			if (mode)	base->ac.policy = data;
